@@ -66,6 +66,7 @@
 #include <unistd.h>
 
 #include "slurm/slurm.h"
+#include "slurm/slurmdb.h"
 #include "slurm/slurm_errno.h"
 
 #include "src/common/assoc_mgr.h"
@@ -602,9 +603,9 @@ static void _load_config(void)
 		max_backfill_job_per_user = 0;
 	}
 	if ((max_backfill_job_per_user != 0) &&
-	    (max_backfill_job_per_user >= max_backfill_job_cnt)) {
-		error("bf_max_job_user >= bf_max_job_test (%u >= %u)",
-		      max_backfill_job_per_user, max_backfill_job_cnt);
+	    (max_backfill_job_per_user > max_backfill_job_cnt)) {
+		info("warning: bf_max_job_user > bf_max_job_test (%u > %u)",
+		     max_backfill_job_per_user, max_backfill_job_cnt);
 	}
 
 	bf_min_age_reserve = 0;
@@ -851,6 +852,26 @@ static bool _job_part_valid(struct job_record *job_ptr,
 	return rc;
 }
 
+/* Determine if job in the backfill queue is still runnable.
+ * Job state could change when lock are periodically released */
+static bool _job_runnable_now(struct job_record *job_ptr)
+{
+	uint16_t cleaning = 0;
+
+	if (!IS_JOB_PENDING(job_ptr))	/* Started in other partition */
+		return false;
+	if (job_ptr->priority == 0)	/* Job has been held */
+		return false;
+	if (IS_JOB_COMPLETING(job_ptr))	/* Started, requeue and completing */
+		return false;
+	select_g_select_jobinfo_get(job_ptr->select_jobinfo,
+				    SELECT_JOBDATA_CLEANING, &cleaning);
+	if (cleaning)			/* Started, requeue and completing */
+		return false;
+
+	return true;
+}
+
 static int _attempt_backfill(void)
 {
 	DEF_TIMERS;
@@ -964,7 +985,7 @@ static int _attempt_backfill(void)
 		struct part_record *part_ptr;
 		bf_parts = list_count(part_list);
 		bf_part_ptr  = xmalloc(sizeof(struct part_record *) * bf_parts);
-		bf_part_jobs = xmalloc(sizeof(int) * bf_parts);
+		bf_part_jobs = xmalloc(sizeof(uint32_t) * bf_parts);
 		part_iterator = list_iterator_create(part_list);
 		i = 0;
 		while ((part_ptr = (struct part_record *)
@@ -1039,8 +1060,8 @@ static int _attempt_backfill(void)
 			if (!job_ptr)	/* All task array elements started */
 				continue;
 		}
-		if (!IS_JOB_PENDING(job_ptr) ||	/* Started in other partition */
-		    (job_ptr->priority == 0))	/* Job has been held */
+
+		if (!_job_runnable_now(job_ptr))
 			continue;
 
 		part_ptr = job_queue_rec->part_ptr;
@@ -1096,6 +1117,15 @@ static int _attempt_backfill(void)
 			}
 		}
 
+		qos_ptr = (slurmdb_qos_rec_t *)job_ptr->qos_ptr;
+		if (part_policy_valid_qos(job_ptr->part_ptr, qos_ptr) !=
+		    SLURM_SUCCESS) {
+			xfree(job_ptr->state_desc);
+			job_ptr->state_reason = WAIT_QOS;
+			last_job_update = now;
+			continue;
+		}
+
 		if (!acct_policy_job_runnable_state(job_ptr) &&
 		    !acct_policy_job_runnable_pre_select(job_ptr))
 			continue;
@@ -1340,8 +1370,7 @@ next_task:
 			if ((job_ptr->magic  != JOB_MAGIC) ||
 			    (job_ptr->job_id != save_job_id))
 				continue;
-			if (!IS_JOB_PENDING(job_ptr) ||	/* Already started */
-			    (job_ptr->priority == 0))	/* Job has been held */
+			if (!_job_runnable_now(job_ptr))
 				continue;
 			if (!avail_front_end(job_ptr))
 				continue;	/* No available frontend */
@@ -1461,7 +1490,7 @@ next_task:
 		if (active_bitmap) {
 			j = _try_sched(job_ptr, &active_bitmap, min_nodes,
 				       max_nodes, req_nodes, exc_core_bitmap);
-			if (j != SLURM_SUCCESS) {
+			if (j == SLURM_SUCCESS) {
 				FREE_NULL_BITMAP(avail_bitmap);
 				avail_bitmap = active_bitmap;
 				active_bitmap = NULL;
@@ -1682,11 +1711,11 @@ next_task:
 				      max_backfill_job_per_part,
 				      max_backfill_job_cnt);
 			} else if ((max_backfill_job_per_user != 0) &&
-				   (max_backfill_job_per_user >=
+				   (max_backfill_job_per_user >
 				    max_backfill_job_cnt)) {
-				error("bf_max_job_user >= bf_max_job_test (%u >= %u)",
-				      max_backfill_job_per_user,
-				      max_backfill_job_cnt);
+				info("warning: bf_max_job_user > bf_max_job_test (%u > %u)",
+				     max_backfill_job_per_user,
+				     max_backfill_job_cnt);
 			}
 			break;
 		}
