@@ -112,7 +112,7 @@ extern int	get_nodes(char *cmd_ptr, int *err_code, char **err_msg)
 	}
 	tmp_char++;
 	lock_slurmctld(node_read_lock);
-	if (strncmp(tmp_char, "ALL", 3) == 0) {
+	if (xstrncmp(tmp_char, "ALL", 3) == 0) {
 		/* report all nodes */
 		buf = _dump_all_nodes(&node_rec_cnt, update_time);
 	} else {
@@ -243,7 +243,7 @@ static char *	_get_node_state(struct node_record *node_ptr)
 	if (!got_select_type) {
 		char * select_type = slurm_get_select_type();
 		if (select_type &&
-		    (strcasecmp(select_type, "select/linear") == 0))
+		    (xstrcasecmp(select_type, "select/linear") == 0))
 			node_allocations = true;
 		else
 			node_allocations = false;
