@@ -72,6 +72,8 @@
  */
 struct select_jobinfo {
 	bitstr_t               *blade_map;
+	bool                    killing; /* (NO NEED TO PACK) used on
+					    a step to signify it being killed */
 	uint16_t                cleaning;
 	uint16_t		magic;
 	uint8_t                 npc;
@@ -196,15 +198,13 @@ static void _clear_event_list(alpsc_ev_app_t *list, int32_t *size);
 static void _start_session(alpsc_ev_session_t **session, int *sessionfd);
 static void *_aeld_event_loop(void *args);
 static void _initialize_event(alpsc_ev_app_t *event,
-			      struct job_record *job_ptr,
 			      struct step_record *step_ptr,
 			      alpsc_ev_app_state_e state);
 static void _copy_event(alpsc_ev_app_t *dest, alpsc_ev_app_t *src);
 static void _free_event(alpsc_ev_app_t *event);
 static void _add_to_app_list(alpsc_ev_app_t **list, int32_t *size,
 			     size_t *capacity, alpsc_ev_app_t *app);
-static void _update_app(struct job_record *job_ptr,
-			struct step_record *step_ptr,
+static void _update_app(struct step_record *step_ptr,
 			alpsc_ev_app_state_e state);
 #endif
 
@@ -247,6 +247,12 @@ static int _run_nhc(nhc_info_t *nhc_info)
 	if (scheduling_disabled)
 		return 0;
 
+	if (slurmctld_conf.select_type_param & CR_NHC_ABSOLUTELY_NO) {
+		error("%s: disabled by NHC_Absolutely_No setting, skipping.",
+		      __func__);
+		return 0;
+	}
+
 #ifdef HAVE_NATIVE_CRAY
 	int argc = 13, status = 1, wait_rc, i = 0;
 	char *argv[argc];
@@ -580,14 +586,15 @@ static void *_aeld_event_loop(void *args)
  * Initialize an alpsc_ev_app_t
  */
 static void _initialize_event(alpsc_ev_app_t *event,
-			      struct job_record *job_ptr,
 			      struct step_record *step_ptr,
 			      alpsc_ev_app_state_e state)
 {
-	hostlist_t hl;
+	struct job_record *job_ptr = step_ptr->job_ptr;
+	hostlist_t hl = NULL;
 	hostlist_iterator_t hlit;
 	char *node;
 	int rv;
+
 	DEF_TIMERS;
 
 	START_TIMER;
@@ -602,36 +609,38 @@ static void _initialize_event(alpsc_ev_app_t *event,
 	event->num_nodes = 0;
 
 	// Fill in nodes and num_nodes if available
-	if (step_ptr->step_layout) {
+	if (step_ptr->step_layout)
 		hl = hostlist_create(step_ptr->step_layout->node_list);
-		if (hl == NULL) {
-			return;
-		}
-		hlit = hostlist_iterator_create(hl);
-		if (hlit == NULL) {
-			hostlist_destroy(hl);
-			return;
-		}
+	else if ((step_ptr->step_id == SLURM_EXTERN_CONT) &&
+		 job_ptr->job_resrcs)
+		hl = hostlist_create(job_ptr->job_resrcs->nodes);
 
-		event->nodes = xmalloc(step_ptr->step_layout->node_cnt
-				       * sizeof(int32_t));
+	if (!hl)
+		return;
 
-		while ((node = hostlist_next(hlit)) != NULL) {
-			rv = sscanf(node, "nid%"SCNd32,
-				    &event->nodes[event->num_nodes]);
-			if (rv) {
-				event->num_nodes++;
-			} else {
-				debug("%s: couldn't parse node %s, skipping",
-				      __func__, node);
-			}
-			free(node);
-		}
-
-		hostlist_iterator_destroy(hlit);
+	hlit = hostlist_iterator_create(hl);
+	if (!hlit) {
 		hostlist_destroy(hl);
+		return;
 	}
 
+	event->nodes = xmalloc(hostlist_count(hl) * sizeof(int32_t));
+
+	while ((node = hostlist_next(hlit))) {
+		rv = sscanf(node, "nid%"SCNd32,
+			    &event->nodes[event->num_nodes]);
+		if (rv) {
+			event->num_nodes++;
+		} else {
+			debug("%s: couldn't parse node %s, skipping",
+			      __func__, node);
+		}
+		free(node);
+	}
+
+	hostlist_iterator_destroy(hlit);
+	hostlist_destroy(hl);
+
 	END_TIMER;
 	if (debug_flags & DEBUG_FLAG_TIME_CRAY)
 		INFO_LINE("call took: %s", TIME_STR);
@@ -702,10 +711,10 @@ static void _add_to_app_list(alpsc_ev_app_t **list, int32_t *size,
  * app list. For suspend/resume apps, edits the app list. Always adds to the
  * event list.
  */
-static void _update_app(struct job_record *job_ptr,
-			struct step_record *step_ptr,
+static void _update_app(struct step_record *step_ptr,
 			alpsc_ev_app_state_e state)
 {
+	struct job_record *job_ptr = step_ptr->job_ptr;
 	uint64_t apid;
 	int32_t i;
 	alpsc_ev_app_t app;
@@ -720,7 +729,7 @@ static void _update_app(struct job_record *job_ptr,
 	}
 
 	// Fill in the new event
-	_initialize_event(&app, job_ptr, step_ptr, state);
+	_initialize_event(&app, step_ptr, state);
 
 	// If there are no nodes, set_application_info will fail
 	if ((app.nodes == NULL) || (app.num_nodes == 0) ||
@@ -1117,7 +1126,18 @@ static void *_step_fini(void *args)
 		nhc_info.is_step = true;
 		nhc_info.apid = SLURM_ID_HASH(step_ptr->job_ptr->job_id,
 					      step_ptr->step_id);
-		nhc_info.exit_code = step_ptr->exit_code;
+
+		/* If we are killing the step it is usually because we
+		 * can't kill it normally.  So NHC will start before
+		 * the step ends.  Setting the exit_code to SIGKILL
+		 * will make NHC do extra tests hopefully helping the
+		 * unkillable process(es).
+		 */
+		if (jobinfo->killing)
+			nhc_info.exit_code = SIGKILL;
+		else
+			nhc_info.exit_code = step_ptr->exit_code;
+
 		nhc_info.user_id = step_ptr->job_ptr->user_id;
 
 		if (!step_ptr->step_layout ||
@@ -1173,55 +1193,6 @@ static void *_step_fini(void *args)
 	return NULL;
 }
 
-static void *_step_kill(void *args)
-{
-	struct step_record *step_ptr = (struct step_record *)args;
-	select_jobinfo_t *jobinfo = NULL;
-	nhc_info_t nhc_info;
-
-	/* Locks: Write job, write node */
-	slurmctld_lock_t job_write_lock = {
-		NO_LOCK, WRITE_LOCK, WRITE_LOCK, NO_LOCK };
-	slurmctld_lock_t job_read_lock = {
-		NO_LOCK, READ_LOCK, NO_LOCK, NO_LOCK };
-
-	if (!step_ptr) {
-		error("%s: no step_ptr given, this should never happen",
-		      __func__);
-		return NULL;
-	}
-
-	memset(&nhc_info, 0, sizeof(nhc_info_t));
-	nhc_info.is_step = true;
-	lock_slurmctld(job_read_lock);
-	nhc_info.jobid = step_ptr->job_ptr->job_id;
-	nhc_info.apid = SLURM_ID_HASH(step_ptr->job_ptr->job_id,
-				      step_ptr->step_id);
-	nhc_info.exit_code = SIGKILL;
-	nhc_info.user_id = step_ptr->job_ptr->user_id;
-
-	if (!step_ptr->step_layout || !step_ptr->step_layout->node_list)
-		nhc_info.nodelist = xstrdup(step_ptr->job_ptr->nodes);
-	else
-		nhc_info.nodelist = xstrdup(step_ptr->step_layout->node_list);
-	unlock_slurmctld(job_read_lock);
-
-	/* run NHC */
-	_run_nhc(&nhc_info);
-	/***********/
-
-	xfree(nhc_info.nodelist);
-
-	_throttle_start();
-	lock_slurmctld(job_write_lock);
-	jobinfo = step_ptr->select_jobinfo->data;
-	jobinfo->cleaning |= CLEANING_COMPLETE;
-	unlock_slurmctld(job_write_lock);
-	_throttle_fini();
-
-	return NULL;
-}
-
 static void _spawn_cleanup_thread(
 	void *obj_ptr, void *(*start_routine) (void *))
 {
@@ -1649,10 +1620,6 @@ extern int select_p_job_init(List job_list)
 
 		while ((job_ptr = list_next(itr))) {
 			jobinfo = job_ptr->select_jobinfo->data;
-			if ((IS_CLEANING_STARTED(jobinfo) &&
-			     !IS_CLEANING_COMPLETE(jobinfo)) ||
-			    IS_JOB_RUNNING(job_ptr))
-				_set_job_running_restore(jobinfo);
 
 			/* We need to resize bitmaps if the
 			 * blades change in count.  We must increase
@@ -1668,6 +1635,11 @@ extern int select_p_job_init(List job_list)
 				jobinfo->used_blades = bit_realloc(
 					jobinfo->used_blades, blade_cnt);
 
+			if ((IS_CLEANING_STARTED(jobinfo) &&
+			     !IS_CLEANING_COMPLETE(jobinfo)) ||
+			    IS_JOB_RUNNING(job_ptr))
+				_set_job_running_restore(jobinfo);
+
 			if (!(slurmctld_conf.select_type_param & CR_NHC_STEP_NO)
 			    && job_ptr->step_list
 			    && list_count(job_ptr->step_list)) {
@@ -2108,7 +2080,7 @@ extern int select_p_job_suspend(struct job_record *job_ptr, bool indf_susp)
 		START_TIMER;
 		i = list_iterator_create(job_ptr->step_list);
 		while ((step_ptr = (struct step_record *)list_next(i))) {
-			_update_app(job_ptr, step_ptr, ALPSC_EV_SUSPEND);
+			_update_app(step_ptr, ALPSC_EV_SUSPEND);
 		}
 		list_iterator_destroy(i);
 		END_TIMER;
@@ -2132,7 +2104,7 @@ extern int select_p_job_resume(struct job_record *job_ptr, bool indf_susp)
 		START_TIMER;
 		i = list_iterator_create(job_ptr->step_list);
 		while ((step_ptr = (struct step_record *)list_next(i))) {
-			_update_app(job_ptr, step_ptr, ALPSC_EV_RESUME);
+			_update_app(step_ptr, ALPSC_EV_RESUME);
 		}
 		list_iterator_destroy(i);
 		END_TIMER;
@@ -2192,7 +2164,7 @@ extern int select_p_step_start(struct step_record *step_ptr)
 
 #ifdef HAVE_NATIVE_CRAY
 	if (aeld_running) {
-		_update_app(step_ptr->job_ptr, step_ptr, ALPSC_EV_START);
+		_update_app(step_ptr, ALPSC_EV_START);
 	}
 #endif
 
@@ -2230,27 +2202,6 @@ extern int select_p_step_start(struct step_record *step_ptr)
 	return other_step_start(step_ptr);
 }
 
-static void _start_killing_step(struct step_record *step_ptr)
-{
-	select_jobinfo_t *jobinfo;
-
-	if (slurmctld_conf.select_type_param & CR_NHC_STEP_NO) {
-		debug3("NHC_No_Steps set not running NHC on steps.");
-		return;
-	}
-
-	if (!step_ptr->select_jobinfo) {
-		debug3("step never got an allocation.");
-		return;
-	}
-
-	jobinfo = step_ptr->select_jobinfo->data;
-	if (jobinfo && !IS_CLEANING_STARTED(jobinfo)) {
-		jobinfo->cleaning |= CLEANING_STARTED;
-		_spawn_cleanup_thread(step_ptr, _step_kill);
-	}
-}
-
 extern int select_p_step_finish(struct step_record *step_ptr, bool killing_step)
 {
 	select_jobinfo_t *jobinfo;
@@ -2259,16 +2210,26 @@ extern int select_p_step_finish(struct step_record *step_ptr, bool killing_step)
 	START_TIMER;
 #ifdef HAVE_NATIVE_CRAY
 	if (aeld_running) {
-		_update_app(step_ptr->job_ptr, step_ptr, ALPSC_EV_END);
+		_update_app(step_ptr, ALPSC_EV_END);
 	}
 #endif
 	/* Send step to db since the step could be deleted by post_job_step()
 	 * before the step is completed and sent to the db (handled in
 	 * _internal_step_complete() in step_mgr.c). post_job_step is called
 	 * after the NHC is run (or immediately with NHC_NO). */
-	jobacct_storage_g_step_complete(acct_db_conn, step_ptr);
+	/* Note if select_g_step_finish is ever called outside of
+	 * _internal_step_complete you most likely will need to call
+	 * this.
+	 */
+	if (killing_step)
+		jobacct_storage_g_step_complete(acct_db_conn, step_ptr);
 
-	if (slurmctld_conf.select_type_param & CR_NHC_STEP_NO) {
+	/* If we are killing the step we want to run the NHC all the
+	 * time because it will log backtraces of unkillable
+	 * processes, so just do it.
+	 */
+	if (!killing_step &&
+	    (slurmctld_conf.select_type_param & CR_NHC_STEP_NO)) {
 		debug3("NHC_No_Steps set not running NHC on steps.");
 		other_step_finish(step_ptr, killing_step);
 		/* free resources on the job */
@@ -2278,14 +2239,6 @@ extern int select_p_step_finish(struct step_record *step_ptr, bool killing_step)
 		return SLURM_SUCCESS;
 	}
 
-	if (killing_step) {
-		_start_killing_step(step_ptr);
-		other_step_finish(step_ptr, killing_step);
-		if (debug_flags & DEBUG_FLAG_TIME_CRAY)
-			INFO_LINE("call took: %s", TIME_STR);
-		return SLURM_SUCCESS;
-	}
-
 #if 0
 	/* The NHC needs to be ran after each step even if the job is about to
 	 * run the NHC for the allocation.  The NHC developers feel this is
@@ -2313,6 +2266,7 @@ extern int select_p_step_finish(struct step_record *step_ptr, bool killing_step)
 		verbose("%s: Cleaned flag already set for step %u.%u",
 			__func__, step_ptr->job_ptr->job_id, step_ptr->step_id);
 	} else {
+		jobinfo->killing = killing_step;
 		jobinfo->cleaning |= CLEANING_STARTED;
 		_spawn_cleanup_thread(step_ptr, _step_fini);
 	}
