@@ -210,8 +210,7 @@ static print_field_t *_get_print_field(char *object)
 		field->name = xstrdup("Class");
 		field->len = 9;
 		field->print_routine = print_fields_str;
-	} else if (!strncasecmp("ClusterNodes", object, MAX(command_len, 8))
-		   || !strncasecmp("NodeNames", object, MAX(command_len, 8))) {
+	} else if (!strncasecmp("ClusterNodes", object, MAX(command_len, 8))) {
 		field->type = PRINT_CLUSTER_NODES;
 		field->name = xstrdup("Cluster Nodes");
 		field->len = 20;
@@ -544,10 +543,10 @@ static print_field_t *_get_print_field(char *object)
 		field->name = xstrdup("NodeCount");
 		field->len = 9;
 		field->print_routine = print_fields_uint;
-	} else if (!strncasecmp("NodeName", object, MAX(command_len, 5))) {
+	} else if (!strncasecmp("NodeNames", object, MAX(command_len, 5))) {
 		field->type = PRINT_NODENAME;
 		field->name = xstrdup("NodeName");
-		field->len = 20;
+		field->len = -15;
 		field->print_routine = print_fields_str;
 	} else if (!strncasecmp("Organization", object, MAX(command_len, 1))) {
 		field->type = PRINT_ORG;
@@ -805,6 +804,11 @@ extern int sacctmgr_remove_assoc_usage(slurmdb_assoc_cond_t *assoc_cond)
 		}
 	}
 
+	if (!assoc_cond->acct_list || !list_count(assoc_cond->acct_list)) {
+		error("An association name is required to remove usage");
+		return SLURM_ERROR;
+	}
+
 	if (!commit_check("Would you like to reset usage?")) {
 		printf(" Changes Discarded\n");
 		return rc;
