@@ -917,6 +917,10 @@ int load_all_part_state(void)
  */
 struct part_record *find_part_record(char *name)
 {
+	if (!part_list) {
+		error("part_list is NULL");
+		return NULL;
+	}
 	return list_find_first(part_list, &list_find_part, name);
 }
 
@@ -1832,10 +1836,14 @@ extern int update_part (update_part_msg_t * part_desc, bool create_flag)
  */
 extern int validate_group(struct part_record *part_ptr, uid_t run_uid)
 {
+	static uid_t last_fail_uid = 0;
+	static struct part_record *last_fail_part_ptr = NULL;
+	static time_t last_fail_time = 0;
+	time_t now;
 #if defined(_SC_GETPW_R_SIZE_MAX)
 	long ii;
 #endif
-	int i = 0, res;
+	int i = 0, res, uid_array_len;
 	size_t buflen;
 	struct passwd pwd, *pwd_result;
 	char *buf;
@@ -1855,6 +1863,17 @@ extern int validate_group(struct part_record *part_ptr, uid_t run_uid)
 		if (part_ptr->allow_uids[i] == run_uid)
 			return 1;
 	}
+	uid_array_len = i;
+
+	/* If this user has failed AllowGroups permission check on this
+	 * partition in past 5 seconds, then do not test again for performance
+	 * reasons. */
+	now = time(NULL);
+	if ((run_uid == last_fail_uid) &&
+	    (part_ptr == last_fail_part_ptr) &&
+	    (difftime(now, last_fail_time) < 5)) {
+		return 0;
+	}
 
 	/* The allow_uids list is built from the allow_groups list,
 	 * and if user/group enumeration has been disabled, it's
@@ -1894,7 +1913,7 @@ extern int validate_group(struct part_record *part_ptr, uid_t run_uid)
 			error("%s: Could not find passwd entry for uid %ld",
 			      __func__, (long) run_uid);
 			xfree(buf);
-			return 0;
+			goto fini;
 		}
 		break;
 	}
@@ -1925,7 +1944,7 @@ extern int validate_group(struct part_record *part_ptr, uid_t run_uid)
 			      __func__, (long) pwd.pw_gid);
 			xfree(buf);
 			xfree(grp_buffer);
-			return 0;
+			goto fini;
 		}
 		break;
 	}
@@ -1944,6 +1963,21 @@ extern int validate_group(struct part_record *part_ptr, uid_t run_uid)
 	xfree(groups);
 	xfree(buf);
 	xfree(grp_buffer);
+
+	if (ret == 1) {
+		debug("UID %ld added to AllowGroup %s of partition %s",
+		      (long) run_uid, grp.gr_name, part_ptr->name);
+		part_ptr->allow_uids =
+			xrealloc(part_ptr->allow_uids,
+				 (sizeof(uid_t) * (uid_array_len + 1)));
+		part_ptr->allow_uids[uid_array_len] = run_uid;
+	}
+
+fini:	if (ret == 0) {
+		last_fail_uid = run_uid;
+		last_fail_part_ptr = part_ptr;
+		last_fail_time = now;
+	}
 	return ret;
 }
 
@@ -1976,6 +2010,36 @@ extern int validate_alloc_node(struct part_record *part_ptr, char* alloc_node)
  	return status;
 }
 
+static int _update_part_uid_access_list(void *x, void *arg)
+{
+	struct part_record *part_ptr = (struct part_record *)x;
+	int *updated = (int *)arg;
+	int i = 0;
+	uid_t *tmp_uids;
+
+	tmp_uids = part_ptr->allow_uids;
+	part_ptr->allow_uids = _get_groups_members(part_ptr->allow_groups);
+
+	if ((!part_ptr->allow_uids) && (!tmp_uids)) {
+		/* no changes, and no arrays to compare */
+	} else if ((!part_ptr->allow_uids) || (!tmp_uids)) {
+		/* one is set when it wasn't before */
+		*updated = 1;
+	} else {
+		/* step through arrays and compare item by item */
+		/* uid_t arrays are terminated with a zero */
+		for (i = 0; part_ptr->allow_uids[i]; i++) {
+			if (tmp_uids[i] != part_ptr->allow_uids[i]) {
+				*updated = 1;
+				break;
+			}
+		}
+	}
+
+	xfree(tmp_uids);
+	return 0;
+}
+
 /*
  * load_part_uid_allow_list - reload the allow_uid list of partitions
  *	if required (updated group file or force set)
@@ -1984,9 +2048,8 @@ extern int validate_alloc_node(struct part_record *part_ptr, char* alloc_node)
 void load_part_uid_allow_list(int force)
 {
 	static time_t last_update_time;
+	int updated = 0;
 	time_t temp_time;
-	ListIterator part_iterator;
-	struct part_record *part_ptr;
 	DEF_TIMERS;
 
 	START_TIMER;
@@ -1995,16 +2058,18 @@ void load_part_uid_allow_list(int force)
 		return;
 	debug("Updating partition uid access list");
 	last_update_time = temp_time;
-	last_part_update = time(NULL);
 
-	part_iterator = list_iterator_create(part_list);
-	while ((part_ptr = (struct part_record *) list_next(part_iterator))) {
-		xfree(part_ptr->allow_uids);
-		part_ptr->allow_uids =
-			_get_groups_members(part_ptr->allow_groups);
+	list_for_each(part_list, _update_part_uid_access_list, &updated);
+
+	/* only update last_part_update when changes made to avoid restarting
+	 * backfill scheduler unnecessarily */
+	if (updated) {
+		debug2("%s: list updated, resetting last_part_update time",
+		       __func__);
+		last_part_update = time(NULL);
 	}
+
 	clear_group_cache();
-	list_iterator_destroy(part_iterator);
 	END_TIMER2("load_part_uid_allow_list");
 }
 
