@@ -141,6 +141,8 @@ int job_format_add_function(List list, int width, bool right_justify,
 	job_format_add_function(list,wid,right,suffix,_print_job_time_submit)
 #define job_format_add_time_start(list,wid,right,suffix) \
 	job_format_add_function(list,wid,right,suffix,_print_job_time_start)
+#define job_format_add_deadline(list,wid,right,suffix) \
+	job_format_add_function(list,wid,right,suffix,_print_job_deadline)
 #define job_format_add_time_end(list,wid,right,suffix) \
 	job_format_add_function(list,wid,right,suffix,_print_job_time_end)
 #define job_format_add_priority(list,wid,right,suffix) \
@@ -159,8 +161,10 @@ int job_format_add_function(List list, int width, bool right_justify,
 	job_format_add_function(list,wid,right,suffix,_print_job_num_nodes)
 #define job_format_add_num_sct(list,wid,right,suffix) \
 	job_format_add_function(list,wid,right,suffix,_print_job_num_sct)
-#define job_format_add_shared(list,wid,right,suffix) \
-	job_format_add_function(list,wid,right,suffix,_print_job_shared)
+#define job_format_add_num_tasks(list,wid,right,suffix) \
+	job_format_add_function(list,wid,right,suffix,_print_job_num_tasks)
+#define job_format_add_over_subscribe(list,wid,right,suffix) \
+	job_format_add_function(list,wid,right,suffix,_print_job_over_subscribe)
 #define job_format_add_contiguous(list,wid,right,suffix) \
 	job_format_add_function(list,wid,right,suffix,_print_job_contiguous)
 #define job_format_add_min_cpus(list,wid,right,suffix) \
@@ -273,6 +277,8 @@ int job_format_add_function(List list, int width, bool right_justify,
 	job_format_add_function(list,wid,right,suffix,_print_job_wait4switch)
 #define job_format_add_tres(list,wid,right,suffix) \
 	job_format_add_function(list,wid,right,suffix,_print_job_tres)
+#define job_format_add_mcs_label(list,wid,right,suffix) \
+	job_format_add_function(list,wid,right,suffix,_print_job_mcs_label)
 
 
 /*****************************************************************************
@@ -330,6 +336,8 @@ int _print_job_time_start(job_info_t * job, int width, bool right_justify,
 			char* suffix);
 int _print_job_time_end(job_info_t * job, int width, bool right_justify,
 			char* suffix);
+int _print_job_deadline(job_info_t * job, int width, bool right_justify,
+			char* suffix);
 int _print_job_priority(job_info_t * job, int width, bool right_justify,
 			char* suffix);
 int _print_job_priority_long(job_info_t * job, int width, bool right_justify,
@@ -348,8 +356,10 @@ int _print_job_num_nodes(job_info_t * job, int width, bool right_justify,
 			char* suffix);
 int _print_job_num_sct(job_info_t * job, int width, bool right_justify,
 		       char* suffix);
-int _print_job_shared(job_info_t * job, int width, bool right_justify,
-		      char* suffix);
+int _print_job_num_tasks(job_info_t * job, int width, bool right_justify,
+		         char* suffix);
+int _print_job_over_subscribe(job_info_t * job, int width, bool right_justify,
+			      char* suffix);
 int _print_job_contiguous(job_info_t * job, int width, bool right_justify,
 			  char* suffix);
 int _print_pn_min_cpus(job_info_t * job, int width, bool right_justify,
@@ -457,6 +467,8 @@ int _print_job_wait4switch(job_info_t * job, int width,
 			   bool right_justify, char* suffix);
 int _print_job_tres(job_info_t * job, int width,
 		    bool right_justify, char *suffix);
+int _print_job_mcs_label(job_info_t * job, int width,
+			 bool right_justify, char* suffix);
 
 /*****************************************************************************
  * Step Print Format Functions
